# Bomberpy
O clássico Bomberman feito em python.

## Instalação
```
$ pip3 install bomberpy
```

## Como jogar
Para iniciar o jogo, digite: 
```
$ bomberpy 
```

## Controles
- w move para cima 
- s move para baixo 
- a move para a esquerda
- d move para a direita
- espaço coloca a bomba